<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Português do Brasil [pt_br]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'ricardo@calepino.com',

	// A
	'access_interface_graphique' => 'Voltar para a interface gráfica completa',
	'access_mode_texte' => 'Exibir a interface textual simplificada',
	'admin_debug' => 'depurar',
	'admin_modifier_article' => 'Editar esta matéria',
	'admin_modifier_auteur' => 'Editar este autor',
	'admin_modifier_breve' => 'Editar esta nota',
	'admin_modifier_mot' => 'Editar esta palavra-chave',
	'admin_modifier_rubrique' => 'Editar esta seção',
	'admin_recalculer' => 'Atualizar esta página',
	'afficher_calendrier' => 'Exibir o calendário',
	'afficher_trad' => 'exibir as traduções',
	'alerte_maj_impossible' => '<b>Atenção!</b> A atualização da base de dados SQL para a versão @version@ não é possível, provavelmente por problema de direitos de edição na base de dados. Por favor, contate o seu provedor de hospedagem.',
	'alerte_modif_info_concourante' => 'ATENÇÃO: Esta informação foi alterada por outra pessoa. O valor atual é:',
	'analyse_xml' => 'Analisar XML',
	'annuler' => 'Cancelar',
	'antispam_champ_vide' => 'Por favor, deixe este campo vazio:',
	'articles_recents' => 'Matérias mais recentes',
	'avis_1_erreur_saisie' => 'Há um erro nos dados informados. Por favor, verifique.', # MODIF
	'avis_archive_incorrect' => 'a cópia de segurança não é um arquivo do SPIP',
	'avis_archive_invalide' => 'a cópia de segurança não é válida',
	'avis_attention' => 'ATENÇÃO!',
	'avis_champ_incorrect_type_objet' => 'Nome de campo @name@ incorreto para objeto do tipo @type@',
	'avis_colonne_inexistante' => 'A coluna @col@ não existe',
	'avis_erreur' => 'Erro: ver abaixo',
	'avis_erreur_connexion' => 'Erro de conexão',
	'avis_erreur_cookie' => 'problema de cookie',
	'avis_erreur_fonction_contexte' => 'Erro de programação. Esta função não deve ser chamada neste contexto.',
	'avis_erreur_mysql' => 'Erro SQL',
	'avis_erreur_sauvegarde' => 'Erro na cópia de segurança (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problema de acesso ao espaço privado',
	'avis_nb_erreurs_saisie' => 'Há @nb@ erros nos dados informados. Por favor, verifique.',

	// B
	'barre_a_accent_grave' => 'Inserir um A maiúsculo com acento grave',
	'barre_aide' => 'utilize os atalhos tipográficos para enriquecer o seu layout',
	'barre_e_accent_aigu' => 'Inserir um E maiúsculo com acento agudo',
	'barre_eo' => 'Inserir um OE contraído',
	'barre_eo_maj' => 'Inserir um OE contraído maiúsculo',
	'barre_euro' => 'Inserir o símbolo € (euro)',
	'barre_gras' => 'Escrever em {{negrito}}',
	'barre_guillemets' => 'envolver em "aspas"',
	'barre_guillemets_simples' => 'Envolver em ’plicas’',
	'barre_intertitre' => 'Transformar em {{{entretítulo}}}',
	'barre_italic' => 'Escrever em {itálico}',
	'barre_lien' => 'Transformar em [link hipertexto->http://...]',
	'barre_lien_input' => 'Informe o endereço do seu link (você pode informar um endereço web do tipo http://www.monsite/com ou simplesmente informar o número de uma matéria deste site.',
	'barre_note' => 'Transformar em [[Nota de pé de página]]',
	'barre_paragraphe' => 'Criar um parágrafo',
	'barre_quote' => '<quote>Citar uma mensagem</quote>',
	'bouton_changer' => 'Alterar',
	'bouton_chercher' => 'Procurar',
	'bouton_choisir' => 'Escolher',
	'bouton_deplacer' => 'Deslocar',
	'bouton_download' => 'Baixar',
	'bouton_enregistrer' => 'Gravar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desativar o sistema interno de mensagens',
	'bouton_radio_envoi_annonces' => 'Enviar os avisos editoriais',
	'bouton_radio_non_envoi_annonces' => 'Não enviar os avisos',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Não enviar a lista de novidades',
	'bouton_recharger_page' => 'atualizar esta página',
	'bouton_telecharger' => 'Transferir',
	'bouton_upload' => 'Upload',
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'tarde',
	'cal_jour_entier' => 'dia todo',
	'cal_matin' => 'manhã',
	'cal_par_jour' => 'calendário por dia',
	'cal_par_mois' => 'calendário por mês',
	'cal_par_semaine' => 'calendário por semana',
	'choix_couleur_interface' => 'côr',
	'choix_interface' => 'escolha da interface',
	'colonne' => 'Coluna',
	'confirm_changer_statut' => 'Atenção, você solicitou a alteração de status deste elemento. Deseja continuar?',
	'correcte' => 'correta',

	// D
	'date_aujourdhui' => 'hoje',
	'date_avant_jc' => 'a.C.',
	'date_dans' => 'entre @delai@',
	'date_de_mois_1' => '@j@ de @nommois@',
	'date_de_mois_10' => '@j@ de @nommois@',
	'date_de_mois_11' => '@j@ de @nommois@',
	'date_de_mois_12' => '@j@ de @nommois@',
	'date_de_mois_2' => '@j@ de @nommois@',
	'date_de_mois_3' => '@j@ de @nommois@',
	'date_de_mois_4' => '@j@ de @nommois@',
	'date_de_mois_5' => '@j@ de @nommois@',
	'date_de_mois_6' => '@j@ de @nommois@',
	'date_de_mois_7' => '@j@ de @nommois@',
	'date_de_mois_8' => '@j@ de @nommois@',
	'date_de_mois_9' => '@j@ de @nommois@',
	'date_demain' => 'amanhã',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ - @heure@',
	'date_fmt_jour_heure_debut_fin' => 'dia @jour@ de @heure_debut@ a @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => 'dia @dtstart@@jour@ de @heure_debut@@dtabbr@ a @dtstart@@heure_fin@@dtend@',
	'date_fmt_jour_mois' => '@jour@ de @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@nomjour@ de @date@',
	'date_fmt_periode' => 'De @date_debut@ a @date_fin@',
	'date_fmt_periode_abbr' => 'De @dtart@@date_debut@@dtabbr@ a @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'De',
	'date_fmt_periode_to' => 'para',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'horas',
	'date_hier' => 'ontem',
	'date_il_y_a' => 'à @delai@',
	'date_jnum1' => '1º',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'domingo',
	'date_jour_1_abbr' => 'dom.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'segunda-feira',
	'date_jour_2_abbr' => 'seg.',
	'date_jour_2_initiale' => 's.',
	'date_jour_3' => 'terça-feira',
	'date_jour_3_abbr' => 'ter.',
	'date_jour_3_initiale' => 't.',
	'date_jour_4' => 'quarta-feira',
	'date_jour_4_abbr' => 'quar.',
	'date_jour_4_initiale' => 'q.',
	'date_jour_5' => 'quinta-feira',
	'date_jour_5_abbr' => 'quin.',
	'date_jour_5_initiale' => 'q.',
	'date_jour_6' => 'sexta-feira',
	'date_jour_6_abbr' => 'sex.',
	'date_jour_6_initiale' => 's.',
	'date_jour_7' => 'sábado',
	'date_jour_7_abbr' => 'sáb.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'dias',
	'date_minutes' => 'minutos',
	'date_mois' => 'meses',
	'date_mois_1' => 'janeiro',
	'date_mois_10' => 'outubro',
	'date_mois_10_abbr' => 'out.',
	'date_mois_11' => 'novembro',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'dezembro',
	'date_mois_12_abbr' => 'dez.',
	'date_mois_1_abbr' => 'jan.',
	'date_mois_2' => 'fevereiro',
	'date_mois_2_abbr' => 'fev.',
	'date_mois_3' => 'março',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'abril',
	'date_mois_4_abbr' => 'abr.',
	'date_mois_5' => 'maio',
	'date_mois_5_abbr' => 'mai.',
	'date_mois_6' => 'junho',
	'date_mois_6_abbr' => 'jun.',
	'date_mois_7' => 'julho',
	'date_mois_7_abbr' => 'jul.',
	'date_mois_8' => 'agosto',
	'date_mois_8_abbr' => 'ago.',
	'date_mois_9' => 'setembro',
	'date_mois_9_abbr' => 'set.',
	'date_saison_1' => 'inverno',
	'date_saison_2' => 'primavera',
	'date_saison_3' => 'verão',
	'date_saison_4' => 'outono',
	'date_secondes' => 'segundos',
	'date_semaines' => 'semanas',
	'date_un_mois' => 'mês',
	'date_une_heure' => 'hora',
	'date_une_minute' => 'minuto',
	'date_une_seconde' => 'segundo',
	'date_une_semaine' => 'semana',
	'dirs_commencer' => 'Para começar realmente a instalação',
	'dirs_preliminaire' => 'Preliminar: <b>Configurar os direitos de acesso</b>',
	'dirs_probleme_droits' => 'Problema com as permissões de acesso',
	'dirs_repertoires_absents' => '<p><b>Os diretórios a seguir não foram encontrados:</b></p><ul>@bad_dirs@.</ul>
<p>É provável que isto se deva a um problema de letras em maiúsculas e minúsculas.
Verifique se as maiúsculas e minúsuculas destes diretórios coincidem exatamente com o que está sendo exibido abaixo; se este não for o caso, renomeie os diretórios com o seu programa de FTP de modo a corrigir o erro.
<p>Uma vêz feita esta manipulação, você poderá ',
	'dirs_repertoires_suivants' => '<p><b>Os diretórios a seguir não estão acessiveis para leitura:</b></p><ul>@bad_dirs@.</ul>
<p>Para corrigir, utilize o seu programa de FTP para configurar os direitos de acesso de cada um destes diretórios. O procedimento está explicado em detalhes no guia de instalação.</p>
<p>Uma vêz feita esta alteração, você poderá ',
	'double_occurrence' => 'Ocorrência dupla de @balise@',

	// E
	'en_cours' => 'em curso',
	'envoi_via_le_site' => 'Envio pelo site',
	'erreur' => 'Erro',
	'erreur_balise_non_fermee' => 'Última tag em aberto:',
	'erreur_technique_ajaxform' => 'Ooops. Um erro inesperado impediu o envio do formulário. Você pode tentar novamente.',
	'erreur_technique_enregistrement_champs' => 'Um erro técnico impediu a gravação correta do campo @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Um erro técnico impediu a gravação.',
	'erreur_texte' => 'erro(s)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'Arquivo @fichier@ não encontrado',
	'form_auteur_confirmation' => 'Confirme o seu endereço de e-mail',
	'form_auteur_email_modifie' => 'O seu endereço de e-mail foi alterado.',
	'form_auteur_envoi_mail_confirmation' => 'Uma mensagem de confirmação acabou de ser enviada para @email@. Você precisa entrar no endereço web mencionado na mensagem para validar o seu endereço de e-mail.',
	'form_auteur_mail_confirmation' => 'Olá,

Você pediu para alterar o seu endereço de e-mail
Para confirmar o seu novo endereço, basta acessar o endereço abaixo (cas contrário, a sua solicitação será ignorada):

    @url@
',
	'form_deja_inscrit' => 'Você já está inscrito.',
	'form_email_non_valide' => 'Seu endereço de e-mail não é válido.',
	'form_forum_access_refuse' => 'Você não tem mais acesso a este site.',
	'form_forum_bonjour' => 'Bom dia @nom@,',
	'form_forum_confirmer_email' => 'Para confirmar o seu endereço de e-mail, clique neste link: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Este endereço de e-mail já está cadastrado, você pode usar a sua senha habitual.',
	'form_forum_identifiant_mail' => 'Seu novo login foi enviado por e-mail.',
	'form_forum_identifiants' => 'Identificadores pessoais',
	'form_forum_indiquer_nom_email' => 'Informe aqui o seu nome  endereço de e-mail. O seu identificador pessoal será enviado de imediato por correio eletrônico.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(esta é uma mensagem automática)',
	'form_forum_pass' => 'senha:',
	'form_forum_probleme_mail' => 'Problema de e-mail: o identificador não pôde ser enviado.',
	'form_forum_voici1' => 'Estes são os seus identificadores para que você possa participar da vida do site "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Estes são os seus identificadores para que você possa propor matérias ao site "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Por favor, informe o seu endereço de e-mail.',
	'form_indiquer_nom' => 'Por favor, informe o seu nome.',
	'form_indiquer_nom_site' => 'Por favor, informe o nome do seu site.',
	'form_pet_deja_enregistre' => 'Este site já está cadastrado',
	'form_pet_signature_pasprise' => 'Sua assinatura não foi computada.',
	'form_prop_confirmer_envoi' => 'Confirmar o envio',
	'form_prop_description' => 'Descrição / comentário',
	'form_prop_enregistre' => 'Sua proposta foi cadastrada, ela aparecerá online após ser validada pelos responsáveis deste site.',
	'form_prop_envoyer' => 'Enviar uma mensagem',
	'form_prop_indiquer_email' => 'Por favor, indique um endereço de e-mail válido',
	'form_prop_indiquer_nom_site' => 'Por favor, informe o nome do site.',
	'form_prop_indiquer_sujet' => 'Por favor, informe um assunto',
	'form_prop_message_envoye' => 'Mensagem enviada',
	'form_prop_non_enregistre' => 'Sua proposta não foi cadastrada.',
	'form_prop_sujet' => 'Assunto',
	'form_prop_url_site' => 'Endereço URL do site',
	'forum_non_inscrit' => 'Você não está inscrito, ou o endereço ou a senha estão errados.',
	'forum_par_auteur' => 'por @auteur@',
	'forum_titre_erreur' => 'Erro...',

	// I
	'ical_texte_rss_articles' => 'O arquivo «backend» das matérias deste site encontra-se no endereço:',
	'ical_texte_rss_articles2' => 'Você pode também obter os arquivos «backend» para as matérias de cada seção do site:',
	'ical_texte_rss_breves' => 'Existe também um arquivo contendo as notas do site. Ao especificar um número de seção, você obterá unicamente as natos dessa seção.',
	'icone_a_suivre' => 'Acompanhar',
	'icone_admin_site' => 'Administração do site',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ajuda',
	'icone_articles' => 'Matérias',
	'icone_auteurs' => 'Autores',
	'icone_brouteur' => 'Navegação rápida',
	'icone_configuration_site' => 'Configuração',
	'icone_configurer_site' => 'Configurar o seu site',
	'icone_creer_nouvel_auteur' => 'Criar um novo autor',
	'icone_creer_rubrique' => 'Criar uma seção',
	'icone_creer_sous_rubrique' => 'Criar uma subseção',
	'icone_deconnecter' => 'Desconectar-se',
	'icone_discussions' => 'Discussões',
	'icone_doc_rubrique' => 'Documentos das seções',
	'icone_ecrire_article' => 'Escrever uma nova matéria',
	'icone_edition_site' => 'Edição',
	'icone_gestion_langues' => 'Gerenciamento de idiomas',
	'icone_informations_personnelles' => 'Informações pessoais',
	'icone_interface_complet' => 'interface completa',
	'icone_interface_simple' => 'Interface simplificada',
	'icone_maintenance_site' => 'Manutenção do site',
	'icone_messagerie_personnelle' => 'Mensagens pessoais',
	'icone_repartition_debut' => 'Exibir a repartição após o início',
	'icone_rubriques' => 'Seções',
	'icone_sauver_site' => 'Backup do site',
	'icone_site_entier' => 'Todo o site',
	'icone_sites_references' => 'Sites referenciados',
	'icone_statistiques' => 'Estatísticas do site',
	'icone_suivi_activite' => 'Acompanhar a vida do site',
	'icone_suivi_actualite' => 'Evolução do site',
	'icone_suivi_pettions' => 'Acompanhar / gerenciar as petições',
	'icone_suivi_revisions' => 'Modificações das matérias',
	'icone_supprimer_document' => 'Suprimir este documento',
	'icone_supprimer_image' => 'Suprimir esta imagem',
	'icone_tous_articles' => 'Todas as suas matérias',
	'icone_tous_auteur' => 'Todos os autores',
	'icone_tous_visiteur' => 'Todos os visitantes',
	'icone_visiter_site' => 'Ver o site público',
	'icone_voir_en_ligne' => 'Ver online',
	'img_indisponible' => 'imagem indisponível',
	'impossible' => 'impossível',
	'info_a_suivre' => 'ACOMPANHAR»',
	'info_acces_interdit' => 'Acesso interdito',
	'info_acces_refuse' => 'Acesso recusado',
	'info_action' => 'Ação: @action@',
	'info_administrer_rubriques' => 'Você pode administrar esta seção e suas subseções',
	'info_adresse_non_indiquee' => 'Você não informou o endereço a testar!',
	'info_aide' => 'AJUDA:',
	'info_ajouter_mot' => 'Incluir esta palavra',
	'info_annonce' => 'AVISO',
	'info_annonces_generales' => 'Avisos gerais:',
	'info_article_propose' => 'Matéria proposta',
	'info_article_publie' => 'Matéria publicada',
	'info_article_redaction' => 'Matéria em fase de redação',
	'info_article_refuse' => 'Matéria recusada',
	'info_article_supprime' => 'Matéria suprimida',
	'info_articles' => 'Matérias',
	'info_articles_a_valider' => 'As matérias para validar',
	'info_articles_nb' => '@nb@ matérias',
	'info_articles_proposes' => 'Matérias propostas',
	'info_articles_un' => '1 matéria',
	'info_auteurs_nombre' => 'autor(es):',
	'info_authentification_ftp' => 'Autenticação (por FTP).',
	'info_breves_2' => 'notas',
	'info_breves_nb' => '@nb@ notas',
	'info_breves_un' => '1 nota',
	'info_connexion_refusee' => 'Conexão recusada',
	'info_contact_developpeur' => 'Por favor, contate um desenvolvedor.',
	'info_contenance' => 'Este site contém:',
	'info_contribution' => 'contribuições',
	'info_copyright' => '@spip@ é um software livre distribuído @lien_gpl@.',
	'info_copyright_doc' => 'Para mais informações, veja o site <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sob licença GPL',
	'info_cours_edition' => 'Em fase de redação',
	'info_creer_repertoire' => 'Por favor, crie um arquivo ou diretório com o nome:',
	'info_creer_repertoire_2' => 'dentro do subdiretório <b>@repertoire@</b>, e depois:',
	'info_creer_vignette' => 'criação automática do ícone',
	'info_creerdansrubrique_non_autorise' => 'Você não tem permissão para criar um conteúdo nesta seção',
	'info_deplier' => 'Expandir',
	'info_descriptif_nombre' => 'descrição(ões):',
	'info_description' => 'Resumo:',
	'info_description_2' => 'Resumo:',
	'info_dimension' => 'Dimensões:',
	'info_documents_nb' => '@nb@ documentos',
	'info_documents_un' => '1 documento',
	'info_ecire_message_prive' => 'Escrever uma mensagem privada',
	'info_email_invalide' => 'Endereço de e-mail inválido.',
	'info_en_cours_validation' => 'Suas matérias em fase de redação',
	'info_en_ligne' => 'Atualmente online:',
	'info_envoyer_message_prive' => 'Enviar uma mensagem privada a este autor',
	'info_erreur_requete' => 'Erro na requisição:',
	'info_erreur_squelette2' => 'Nenhum template <b>@fichier@</b> está disponível...',
	'info_erreur_systeme' => 'Erro do sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'É possível que não haja espaço livre em disco, ou que a base de dados esteja corrompida.<br />
<span style="color:red;">Tente <a href=\'@script@\'>reparar a base</a>, ou contate o seu serviço de hospedagem.</span>',
	'info_fini' => 'Terminou!',
	'info_format_image' => 'Formatos das imagens que podem ser utilizados para criar os ícones @gd_formats@.',
	'info_format_non_defini' => 'formato não definido',
	'info_grand_ecran' => 'Alta resolução',
	'info_image_aide' => 'AJUDA',
	'info_image_process_titre' => 'Método de criação dos ícones',
	'info_impossible_lire_page' => '<b>Erro!</b> Impossível ler a página <tt><html>@test_proxy@</html></tt> via proxy',
	'info_installation_systeme_publication' => 'Instalação do sistema de publicação...',
	'info_installer_documents' => 'Você pode instalar automaticamente todos os documentos contídos no diretório @upload@.',
	'info_installer_ftp' => 'Como administrador, você pode transferir (por FTP) arquivos para o diretório @upload@ para, em seguida, selecioná-los aqui diretamente.',
	'info_installer_images' => 'Você pode transferir imagens nos formatos JPEG, GIF e PNG.',
	'info_installer_images_dossier' => 'Transferir as imagens para o diretório @upload@ para poder selecioná-las aqui.',
	'info_interface_complete' => 'interface completa',
	'info_interface_simple' => 'Interface simplificada',
	'info_joindre_document_article' => 'Você pode anexar a esta matéria documentos dos tipos a seguir',
	'info_joindre_document_rubrique' => 'Você pode anexar a esta seção documentos dos tipos a seguir',
	'info_joindre_documents_article' => 'Você pode anexar à sua matéria documentos dos tipos a seguir:',
	'info_l_article' => 'a matéria',
	'info_la_breve' => 'a nota',
	'info_la_rubrique' => 'a seção',
	'info_langue_principale' => 'Idioma principal do site',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'por @les_auteurs@',
	'info_logo_format_interdit' => 'Apenas os ícones nos formatos @formats@ estão autorizados.',
	'info_logo_max_poids' => 'Os ícones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_mail_fournisseur' => 'voce@seudominio.com.br',
	'info_message_2' => 'MENSAGEM',
	'info_message_supprime' => 'MENSAGEM EXCLUÍDA',
	'info_messages_nb' => '@nb@ mensagens',
	'info_messages_un' => '1 mensagem',
	'info_mise_en_ligne' => 'Data de publicação online:',
	'info_modification_parametres_securite' => 'modificações dos parâmetros de segurança',
	'info_mois_courant' => 'No mês corrente:',
	'info_mot_cle_ajoute' => 'A palavra-chave a seguir foi associada a',
	'info_multi_herit' => 'Idioma padrão',
	'info_multi_langues_soulignees' => 'Os <u>idiomas sublinhados</u> dispõem de tradução total ou parcial dos textos da interface. Se você escolher esses idiomas, diversos elementos do site público (datas, formulários) são traduzidos automaticamente. Para os idiomas não sublinhados, estes elementos aparecerão no idioma principal do site.',
	'info_multilinguisme' => 'Multilinguismo',
	'info_nom_non_utilisateurs_connectes' => 'Seu nome não aparece na relação de usuários conectados.',
	'info_nom_utilisateurs_connectes' => 'Seu nome aparecerá na relação de usuários conectados.',
	'info_nombre_en_ligne' => 'Online neste momento:',
	'info_non_resultat' => 'Nenhum resultados para "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Você não utiliza o sistema de mensagens deste site.',
	'info_nouveau_message' => 'VOCÊ TEM UMA NOVA MENSAGEM',
	'info_nouveaux_messages' => 'VOCÊ TEM @total_messages@ MENSAGENS NOVAS',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Esta informação é obrigatória',
	'info_pense_bete' => 'LEMBRETE',
	'info_petit_ecran' => 'Baixa resolução',
	'info_petition_close' => 'Petição fechada',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Várias palavras-chave encontradas para "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portfólio automático:',
	'info_premier_resultat' => '[@debut_limit@ primeiros resultados de @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primeiros resultados de @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propõe: @titre@',
	'info_propose_2' => 'Matéria proposta
----------------',
	'info_propose_3' => 'A matéria "@titre@" foi proposta para publicação.',
	'info_propose_4' => 'Você está convidado a consultá-la e dar sua opinião',
	'info_propose_5' => 'no fórum a ela anexado. Ela está disponível no endereço:',
	'info_publie_01' => 'A matéria "@titre@" foi validada por @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICADO: @titre@',
	'info_publie_2' => 'Matéria publicada
-----------------',
	'info_rechercher' => 'Procurar',
	'info_rechercher_02' => 'Procurar:',
	'info_remplacer_vignette' => 'Substituir o ícone padrão por um logo personalizado:',
	'info_rubriques_nb' => '@nb@ seções',
	'info_rubriques_un' => '1 seção',
	'info_sans_titre_2' => 'sem título',
	'info_selectionner_fichier' => 'Você pode escolher um arquivo do diretório @upload@',
	'info_selectionner_fichier_2' => 'Selecionar um arquivo:',
	'info_sites_nb' => '@nb@ sites',
	'info_sites_un' => '1 site',
	'info_supprimer_vignette' => 'excluir o ícone',
	'info_symbole_bleu' => 'O ícone <b>azul</b> indica um <b>lembrete</b>: ou seja, uma mensagem para seu uso pessoal.',
	'info_symbole_jaune' => 'O ícone <b>amarelo</b> indica um  <b>anúncio para todos os redatores</b>: modificável por todos os administradores, e visível por todos os redatores.',
	'info_symbole_vert' => 'O ícone <b>verde</b> indica as  <b>mensagens trocadas com outros usuários</b> do site.',
	'info_telecharger_nouveau_logo' => 'Transferir um novo logo:',
	'info_telecharger_ordinateur' => 'Tranferir do seu computador:',
	'info_tous_resultats_enregistres' => '[todos os resultados são gravados]',
	'info_tout_afficher' => 'Mostrar todas',
	'info_travaux_texte' => 'Este site ainda não está configurado. Volte mais tarde...',
	'info_travaux_titre' => 'Site em manutenção',
	'info_trop_resultat' => 'Resultados de mais para "@cherche_mot@"; por favor, refine a busca.',
	'info_utilisation_messagerie_interne' => 'Você usa o sistema interno de mensagens deste site.',
	'info_valider_lien' => 'validar este link',
	'info_verifier_image' => ', verifique se as suas imagens foram transferidas corretamente.',
	'info_vignette_defaut' => 'Ícone padrão',
	'info_vignette_personnalisee' => 'Ícone personalizado',
	'info_visite' => 'visita:',
	'info_vos_rendez_vous' => 'Seus encontros futuros',
	'infos_vos_pense_bete' => 'Seus lembretes',

	// L
	'label_ajout_id_rapide' => 'Ajuda rápida',
	'label_poids_fichier' => 'Tamanho',
	'lien_afficher_icones_seuls' => 'Exibir apenas os ícones',
	'lien_afficher_texte_icones' => 'Exibir ícones e texto',
	'lien_afficher_texte_seul' => 'Exibir apenas o texto',
	'lien_liberer' => 'liberar',
	'lien_liberer_tous' => 'liberar todas',
	'lien_nouvea_pense_bete' => 'NOVO LEMBRETE',
	'lien_nouveau_message' => 'NOVA MENSAGEM',
	'lien_nouvelle_annonce' => 'NOVO ANÚNCIO',
	'lien_petitions' => 'PETIÇÃO',
	'lien_popularite' => 'popularidade: @popularite@%',
	'lien_racine_site' => 'RAIZ DO SITE',
	'lien_reessayer' => 'tente novamente',
	'lien_repondre_message' => 'Responder a esta mensagem',
	'lien_supprimer' => 'excluir',
	'lien_tout_afficher' => 'Mostrar tudo',
	'lien_visite_site' => 'visitar este site',
	'lien_visites' => '@visites@ visitas',
	'lien_voir_auteur' => 'Ver este autor',
	'ligne' => 'Linha',
	'login' => 'Conexão',
	'login_acces_prive' => 'acesso ao espaço privado',
	'login_autre_identifiant' => 'conectar-se com outra identificação',
	'login_cookie_accepte' => 'Por favor, configure o seu navegador para aceitá-los (pelo menos para este site).',
	'login_cookie_oblige' => 'Para você se identificar de modo seguro neste site, você precisa aceitar cookies.',
	'login_deconnexion_ok' => 'Desconexão efetuada.',
	'login_erreur_pass' => 'Erro de senha.',
	'login_espace_prive' => 'espaço privado',
	'login_identifiant_inconnu' => 'O identificador «@login@» não está cadastrado.',
	'login_login' => 'Login:',
	'login_login2' => 'Login',
	'login_login_pass_incorrect' => '(Login ou senha incorreta.)',
	'login_motpasseoublie' => 'esqueceu sua senha?',
	'login_non_securise' => 'Atenção, este formulário não é seguro.
Se você não quiser que a sua senha possa ser interceptada na rede, por favor ative o Javascript no seu navegador e',
	'login_nouvelle_tentative' => 'Tentar novamente',
	'login_par_ici' => 'VocÊ está registrado... por aqui...',
	'login_pass2' => 'Senha:',
	'login_preferez_refuser' => '<b>Se você prefere recusar os cookies</b>, um outro método de conexão (menos seguro) está disponível:',
	'login_recharger' => 'atualizar esta página',
	'login_rester_identifie' => 'Manter-se identificado por alguns dias',
	'login_retour_public' => 'Voltar ao site público',
	'login_retour_site' => 'Voltar ao site público',
	'login_retoursitepublic' => 'voltar ao site público',
	'login_securise' => 'Login seguro',
	'login_sinscrire' => 'cadastrar-se',
	'login_test_navigateur' => 'testar navegador/reconexão',
	'login_verifiez_navigateur' => '(Verifique sempre se o seu navegador não está memorizando a sua senha...)',

	// M
	'masquer_colonne' => 'Ocultar esta coluna',
	'masquer_trad' => 'esconder as traduções',
	'module_fichiers_langues' => 'Arquivos de idioma',

	// N
	'navigateur_pas_redirige' => 'Se o seu navegador não o redirecionar, clique aqui para continuar.',
	'numero' => 'Número',

	// O
	'occurence' => 'Ocorrência',
	'onglet_affacer_base' => 'Apagar a base',
	'onglet_auteur' => 'O autor',
	'onglet_contenu_site' => 'Conteúdo do site',
	'onglet_evolution_visite_mod' => 'Evolução',
	'onglet_fonctions_avances' => 'Funções avançadas',
	'onglet_informations_personnelles' => 'Informações pessoais',
	'onglet_interactivite' => 'Interatividade',
	'onglet_messagerie' => 'Sistema de mensagens',
	'onglet_repartition_rubrique' => 'Repartição por seções',
	'onglet_save_restaur_base' => 'Fazer cópia de segurança/restaurar a base',
	'onglet_vider_cache' => 'Esvaziar o cache',

	// P
	'pass_choix_pass' => 'Por favor, escolha a sua nova senha:',
	'pass_erreur' => 'Erro',
	'pass_erreur_acces_refuse' => '<b>Erro:</b> você não tem mais acesso a este site.',
	'pass_erreur_code_inconnu' => '<b>Erro:</b> este login não corresponde a nenhum visitante com permissão de acesso a este site.',
	'pass_erreur_non_enregistre' => '<b>Erro:</b> o e-mail <tt>@email_oubli@</tt> não está cadastrado neste site.',
	'pass_erreur_non_valide' => '<b>Erro:</b> o e-mail <tt>@email_oubli@</tt> não é válido!',
	'pass_erreur_probleme_technique' => '<b>Erro:</b> este e-mail não pôde ser enviado devido a um problema técnico.',
	'pass_espace_prive_bla' => 'O espaço privado deste site é aberto aos visitantes, após inscrição. Uma vez cadastrado, você poderá consultar as matérias em fase de redação, propor a publicação de novas matérias e participar de todos os fóruns.',
	'pass_forum_bla' => 'Você soliciou a participação num fórum reservado a visitantes registrados.',
	'pass_indiquez_cidessous' => 'Informe abaixo o endereço de e-mail com o qual você se cadastrou anteriormente. Você receberá um e-mail lhe indicando os procedimentos a seguir para recuperar o seu acesso.',
	'pass_mail_passcookie' => '(esta é uma mensagem automática)
Para recuperar o seu acesso ao site
@nom_site_spip@ (@adresse_site@)

clique por favor no endereço a seguir:

    @sendcookie@

Você poderá então cadastrar uma nova senha
e reconectar-se com o site.

',
	'pass_mot_oublie' => 'Senha esquecida',
	'pass_nouveau_enregistre' => 'Sua nova senha foi cadastrada.',
	'pass_nouveau_pass' => 'Nova senha',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Esquecimento de senha',
	'pass_procedure_changer' => 'Para alterar a sua senha, é necessário verificar a sua identidade. Para isso, informe o endereço de e-mail associado a esta sua conta.', # MODIF
	'pass_quitter_fenetre' => 'Fechar esta janela',
	'pass_rappel_login' => 'Lembrete: seu login é «@login@».',
	'pass_recevoir_mail' => 'Você receberá um e-mail explicando como você pode recuperar o acesso ao site.',
	'pass_retour_public' => 'Voltar para o site público',
	'pass_rien_a_faire_ici' => 'Nada a fazer aqui.',
	'pass_vousinscrire' => 'Cadastrar-se neste site',
	'precedent' => 'precedente',
	'previsualisation' => 'Visualização',
	'previsualiser' => 'Visualizar',

	// R
	'retour' => 'Voltar',

	// S
	'spip_conforme_dtd' => 'O SPIP considera este documento de acordo com o seu DOCTYPE:',
	'squelette' => 'template',
	'squelette_inclus_ligne' => 'template incluído, linha',
	'squelette_ligne' => 'template, linha',
	'stats_visites_et_popularite' => '@visites@ visitas; popularidade: @popularite@',
	'suivant' => 'seguinte',

	// T
	'taille_go' => '@taille@ GB',
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => ' @taille@ bytes',
	'texte_actualite_site_1' => 'Quando você estiver mais familiarizado com a interface, clique em «',
	'texte_actualite_site_2' => 'interface completa',
	'texte_actualite_site_3' => '» para abrir mais possibilidades.',
	'texte_creation_automatique_vignette' => 'A criação automática de ícones de visualização está ativada neste site. Se você transferir por este formulário imagens no(s) formato(s) @gd_formats@, elas serão acompanhadas de um ícone com o tamanho máximo de @taille_preview@ pixels.',
	'texte_documents_associes' => 'Os documentos a seguir estão associados à matéria,
mas eles não foram inseridos diretamente. Dependendo da elaboração dos templates do site público, eles podem aparecer como documentos anexados.',
	'texte_erreur_mise_niveau_base' => 'Erro da base de dados durante a atualização.
A imagem <b>@fichier@</b> não passou (matéria @id_article@).
Anote esta referência, tente novamente a atualização e, finalmente, verifique se as imagens aparecem nas matérias.',
	'texte_erreur_visiteur' => 'Você tentou acessar o espaço restrito com um login que não tem a permissão necessária.',
	'texte_inc_auth_1' => 'Você se identificou com o login <b>@auth_login@</b>, mas ele não consta (mais) na base.
Tente se',
	'texte_inc_auth_2' => 'reconectar',
	'texte_inc_auth_3' => ', após ter eventualmente saído e reiniciado o seu navegador.',
	'texte_inc_config' => 'As modificações efetuadas nestas páginas influem consideravelmente no funcionamento do seu site. É recomendável não intervir enquanto você não estiver familiarizado com o funcionamento do sistema SPIP.<br /><br /><b>Geralmente, é fortemente aconselhável deixar a carga destas páginas para o webmaster principal do seu site.</b>',
	'texte_inc_meta_1' => 'O sistema encontrou um erro durante a escrita do arquivo <code>@fichier@</code>. Como administrador do site, queira por favor,',
	'texte_inc_meta_2' => 'Verificar os direitos de escrita',
	'texte_inc_meta_3' => 'no diretório <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'em fase de redação',
	'texte_statut_poubelle' => 'na lixeira',
	'texte_statut_propose_evaluation' => 'proposto para avaliação',
	'texte_statut_publie' => 'publicado online',
	'texte_statut_refuse' => 'recusado',
	'titre_ajouter_mot_cle' => 'INCLUIR UMA PALAVRA-CHAVE:',
	'titre_cadre_raccourcis' => 'ATALHOS:',
	'titre_changer_couleur_interface' => 'Alterar a côr da interface',
	'titre_image_admin_article' => 'Você pode administrar esta matéria',
	'titre_image_administrateur' => 'Administrador',
	'titre_image_aide' => 'Ajuda sobre este elemento',
	'titre_image_auteur_supprime' => 'Autor excluído',
	'titre_image_redacteur' => 'Redator sem acesso',
	'titre_image_redacteur_02' => 'Redator',
	'titre_image_selecteur' => 'Ver a lista',
	'titre_image_visiteur' => 'Visitante',
	'titre_joindre_document' => 'INCLUIR UM DOCUMENTO',
	'titre_mots_cles' => 'PALAVRAS-CHAVE',
	'titre_probleme_technique' => 'Atenção: um problema técnico (servidor SQL) impede o acesso a esta parte do site. Agradecemos sua compreensão.',
	'titre_publier_document' => 'PUBLICAR UM DOCUMENTO NESTA SEÇÃO',
	'titre_signatures_attente' => 'Assinaturas aguardando validação',
	'titre_signatures_confirmees' => 'Assinaturas confirmadas',
	'titre_statistiques' => 'Estatísticas do site',
	'titre_titre_document' => 'Título do documento:',
	'todo' => 'breve',
	'trad_definir_reference' => 'Escolher "@titre@" como referência das traduções',
	'trad_reference' => '(matéria das traduções)',

	// Z
	'zbug_balise_b_aval' => ': tag B colocada após BOUCLE',
	'zbug_balise_inexistante' => 'Tag @balise@ mal declarada para @from@',
	'zbug_balise_sans_argument' => 'Falta um arqumento na tag @balise@',
	'zbug_boucle' => 'laço',
	'zbug_boucle_recursive_undef' => 'Laço recursivo não definido: @nom@',
	'zbug_calcul' => 'cálculo',
	'zbug_champ_hors_boucle' => 'Campo @champ@ fora do laço',
	'zbug_champ_hors_motif' => 'Campo @champ@ fora de um contexto @motif@',
	'zbug_code' => 'código',
	'zbug_critere_inconnu' => 'Critério @critere@ desconhecido',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} em uma tabela sem chave primária atômica',
	'zbug_distant_interdit' => 'Externa interdita',
	'zbug_doublon_table_sans_cle_primaire' => 'Duplicação em tabela sem chave primária atômica',
	'zbug_doublon_table_sans_index' => 'Doublons em uma tabela sem index',
	'zbug_erreur_boucle_double' => 'Dupla definição do laço @id@',
	'zbug_erreur_boucle_fermant' => 'Laço @id@ não fechado',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxe do laço @id@ está incorreta',
	'zbug_erreur_compilation' => 'Erro de compilação',
	'zbug_erreur_execution_page' => 'Erro de execução',
	'zbug_erreur_filtre' => 'Filtro @filtre@ não definido',
	'zbug_erreur_meme_parent' => 'O critério {meme_parent} aplica-se exclusivamente aos laços (FORUMS) ou (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Erro(s) no template',
	'zbug_hors_compilation' => 'Fora de Compilação',
	'zbug_info_erreur_squelette' => 'Erro no site',
	'zbug_inversion_ordre_inexistant' => 'Inversão de uma ordem inexistente',
	'zbug_pagination_sans_critere' => 'Tag #PAGINATION sem critério {pagination} ou usada dentro de uma boucle recursiva',
	'zbug_parametres_inclus_incorrects' => 'Parâmetro de inclusão incorreto: @param@',
	'zbug_profile' => 'Tempo de processamento: @time@',
	'zbug_resultat' => 'resultado',
	'zbug_serveur_indefini' => 'Sevidor SQL não definido',
	'zbug_statistiques' => 'Estatísticas das requisições SQL classificadas por duração',
	'zbug_table_inconnue' => 'Tabela SQL «@table@» desconhecida',
	'zxml_connus_attributs' => 'atributos conhecidos',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atributo desconhecido',
	'zxml_inconnu_balise' => 'tag desconhecida',
	'zxml_inconnu_entite' => 'entidade desconhecida',
	'zxml_inconnu_id' => 'ID desconhecida',
	'zxml_mais_de' => 'mas de',
	'zxml_non_conforme' => 'não está de acordo com o motivo',
	'zxml_non_fils' => 'não é filho de',
	'zxml_nonvide_balise' => 'tag não vazia',
	'zxml_obligatoire_attribut' => 'atributo obrigatório mas ausente em',
	'zxml_succession_fils_incorrecte' => 'sucessão de filhos incorreta',
	'zxml_survoler' => 'sobrepor para ver os corretos',
	'zxml_valeur_attribut' => 'valor do atributo',
	'zxml_vide_balise' => 'tag vazia',
	'zxml_vu' => 'previsualização'
);

?>
